macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Expand description
Analogue of std::println! that allows for printing to the console during a build
script.
macro_rules! println {
() => { ... };
($($arg:tt)*) => { ... };
}Analogue of std::println! that allows for printing to the console during a build
script.